@@ -103,14 +103,11 @@ class CalcZone(object):
         data["zone_id"] = self.zone_id
         data["name"] = self.name
         data["offset"] = self.offset
-        data["fov_vert"] = self.fov_vert
-        data["fov_horiz"] = self.fov_horiz
-        data["vert"] = self.vert
-        data["horiz"] = self.horiz
         data["dose"] = self.dose
         data["hours"] = self.hours
         data["enabled"] = self.enabled
         data["show_values"] = self.show_values
+        data["colormap"] = self.colormap
         data["x1"] = self.x1
         data["x2"] = self.x2
         data["x_spacing"] = self.x_spacing
@@ -121,6 +118,12 @@ class CalcZone(object):
         # data["num_y"] = self.num_y
         if isinstance(self, CalcPlane):
             data["height"] = self.height
+            data["fov_vert"] = self.fov_vert
+            data["fov_horiz"] = self.fov_horiz
+            data["vert"] = self.vert
+            data["horiz"] = self.horiz
+            data["ref_surface"] = self.ref_surface
+            data["direction"] = self.direction
             data["calctype"] = "Plane"
         elif isinstance(self, CalcVol):
             data["z1"] = self.z1
@@ -205,6 +208,11 @@ class CalcZone(object):
                 val = testval  # if no rounded value works use the original value
         return val
 
+    def _check_spacing(self, spacing, dim):
+        if spacing is not None:
+            if spacing > dim:
+                raise ValueError("Spacing value cannot be larger than dimension")
+
     def calculate_values(self, lamps, ref_manager=None, hard=False):
         """
         Calculate all the values for all the lamps
@@ -383,7 +391,16 @@ class CalcVol(CalcZone):
         """
         return []
 
-    def set_dimensions(self, x1=None, x2=None, y1=None, y2=None, z1=None, z2=None, preserve_spacing=True):
+    def set_dimensions(
+        self,
+        x1=None,
+        x2=None,
+        y1=None,
+        y2=None,
+        z1=None,
+        z2=None,
+        preserve_spacing=True,
+    ):
         self.x1 = self.x1 if x1 is None else x1
         self.x2 = self.x2 if x2 is None else x2
         self.y1 = self.y1 if y1 is None else y1
@@ -397,9 +414,9 @@ class CalcVol(CalcZone):
         yr = abs(self.y2 - self.y1)
         zr = abs(self.z2 - self.z1)
         if preserve_spacing:
-            self.num_x = max(int(round(xr / self.x_spacing)),1)
-            self.num_y = max(int(round(yr / self.y_spacing)),1)
-            self.num_z = max(int(round(zr / self.z_spacing)),1)
+            self.num_x = max(int(round(xr / self.x_spacing)), 1)
+            self.num_y = max(int(round(yr / self.y_spacing)), 1)
+            self.num_z = max(int(round(zr / self.z_spacing)), 1)
         else:
             deg_x = -int(np.floor(np.log10(xr / self.num_x)))
             deg_y = -int(np.floor(np.log10(yr / self.num_y)))
@@ -410,19 +427,25 @@ class CalcVol(CalcZone):
             self.x_spacing = self._set_spacing(self.x1, self.x2, self.num_x, default_xs)
             self.y_spacing = self._set_spacing(self.y1, self.y2, self.num_y, default_ys)
             self.z_spacing = self._set_spacing(self.z1, self.z2, self.num_z, default_zs)
-        
+
         self._update()
 
     def set_spacing(self, x_spacing=None, y_spacing=None, z_spacing=None):
         """
         set the spacing desired in the dimension
         """
+        xr = abs(self.x2 - self.x1)
+        yr = abs(self.y2 - self.y1)
+        zr = abs(self.z2 - self.z1)
+        self._check_spacing(x_spacing, xr)
+        self._check_spacing(y_spacing, yr)
+        self._check_spacing(z_spacing, zr)
         self.x_spacing = self.x_spacing if x_spacing is None else abs(x_spacing)
         self.y_spacing = self.y_spacing if y_spacing is None else abs(y_spacing)
         self.z_spacing = self.z_spacing if z_spacing is None else abs(z_spacing)
-        numx = int(round(abs(self.x2 - self.x1) / self.x_spacing))
-        numy = int(round(abs(self.y2 - self.y1) / self.y_spacing))
-        numz = int(round(abs(self.z2 - self.z1) / self.z_spacing))
+        numx = int(round(xr / self.x_spacing))
+        numy = int(round(yr / self.y_spacing))
+        numz = int(round(zr / self.z_spacing))
         self.num_x = numx
         self.num_y = numy
         self.num_z = numz
@@ -656,15 +679,23 @@ class CalcPlane(CalcZone):
 
         if x_spacing is None:  # set from num_points if spacing is not provided
             self.num_x = default_num_x if num_x is None else int(num_x)
+            if self.num_x < 1:
+                self.num_x = 1
             self.x_spacing = self._set_spacing(self.x1, self.x2, self.num_x, default_xs)
         else:
             self.x_spacing = x_spacing
+            if self.x_spacing > xr:
+                self.x_spacing = xr
             self.num_x = int(round(xr / self.x_spacing))
         if y_spacing is None:
             self.num_y = default_num_y if num_y is None else int(num_y)
+            if self.num_y < 1:
+                self.num_y = 1
             self.y_spacing = self._set_spacing(self.y1, self.y2, self.num_y, default_ys)
         else:
             self.y_spacing = y_spacing
+            if self.y_spacing > yr:
+                self.y_spacing = yr
             self.num_y = int(round(yr / self.y_spacing))
 
         self._update()
@@ -755,10 +786,14 @@ class CalcPlane(CalcZone):
 
     def set_spacing(self, x_spacing=None, y_spacing=None):
         """set the fineness of the grid spacing and update the coordinate points"""
+        xr = abs(self.x2 - self.x1)
+        yr = abs(self.y2 - self.y1)
+        self._check_spacing(x_spacing, xr)
+        self._check_spacing(y_spacing, yr)
         self.x_spacing = self.x_spacing if x_spacing is None else abs(x_spacing)
         self.y_spacing = self.y_spacing if y_spacing is None else abs(y_spacing)
-        self.num_x = int(round(abs(self.x2 - self.x1) / self.x_spacing))
-        self.num_y = int(round(abs(self.y2 - self.y1) / self.y_spacing))
+        self.num_x = int(round(xr / self.x_spacing))
+        self.num_y = int(round(yr / self.y_spacing))
         self._update()
         return self
 
@@ -888,7 +923,7 @@ class CalcPlane(CalcZone):
 
         # points = [np.unique(val) for val in self.coords.T]
         # num_x, num_y, *rest = [len(val) for val in points if len(val) > 1]
-        num_x, num_y = self.num_x, self.num_y #tmp
+        num_x, num_y = self.num_x, self.num_y  # tmp
 
         values = self.get_values()
         if values is None:
@@ -905,8 +940,8 @@ class CalcPlane(CalcZone):
         if len(np.unique(xpoints)) == 1 and len(np.unique(ypoints)) == 1:
             xpoints = self.coords.T[0].reshape(num_x, num_y)[0].tolist()
             ypoints = self.coords.T[1].reshape(num_x, num_y).T[0].tolist()
-            vals = vals.T
-            zvals = zvals.T
+            vals = np.array(vals).T.tolist()
+            zvals = zvals.T.tolist()
 
         rows = [[""] + xpoints]
 
