@@ -111,12 +111,12 @@ class ReflectanceManager:
         if wall_id is None:
             for wall in self.keys:
                 # set for all walls
-                self.surfaces[wall].plane.set_spacing(num_x=num_x, num_y=num_y)
+                self.surfaces[wall].plane.set_num_points(num_x=num_x, num_y=num_y)
         else:
             if wall_id not in self.keys:
                 raise KeyError(f"wall_id must be in {self.keys}")
             else:
-                self.surfaces[wall_id].plane.set_spacing(num_x=num_x, num_y=num_y)
+                self.surfaces[wall_id].plane.set_num_points(num_x=num_x, num_y=num_y)
         self._update_points()
 
     def _initialize_surfaces(self):
@@ -131,6 +131,7 @@ class ReflectanceManager:
                 ref_surface,
                 direction,
             ) = self._get_surface_dimensions(wall)
+
             plane = CalcPlane(
                 zone_id=wall,
                 x1=x1,
@@ -206,6 +207,7 @@ class ReflectanceManager:
             x1, x2, y1, y2, height, _, _ = self._get_surface_dimensions(wall)
             surface.plane.height = height
             surface.plane.set_dimensions(x1, x2, y1, y2, preserve_spacing=False)
+        self._update_points()
 
     def calculate_incidence(self, lamps, hard=False):
         """
