@@ -234,10 +234,10 @@ class Room:
 
     # --------------------- Misc flags -----------------------
 
-    def set_standard(self, standard):
+    def set_standard(self, standard, preserve_spacing=True):
         """update the photobiological safety standard the Room is subject to"""
         self.standard = standard
-        self.scene.update_standard_zones(standard)
+        self.scene.update_standard_zones(standard, preserve_spacing=preserve_spacing)
         return self
 
     # --------------------- Reflectance ----------------------
@@ -260,6 +260,14 @@ class Room:
         )
         return self
 
+    def set_reflectance_num_points(self, num_x=None, num_y=None, wall_id=None):
+        """
+        set the number of calculation points for the reflective walls
+        If wall_id is none, the value is set for all walls.
+        """
+        self.ref_manager.set_num_points(num_x=num_x, num_y=num_y, wall_id=wall_id)
+        return self
+
     def set_max_num_passes(self, max_num_passes):
         """set the maximum number of passes for the interreflection module"""
         self.ref_manager.max_num_passes = max_num_passes
@@ -275,14 +283,16 @@ class Room:
 
     # -------------- Dimensions and Units -----------------------
 
-    def set_units(self, units, unit_mode="auto"):
+    def set_units(self, units, unit_mode="auto", preserve_spacing=True):
         """set room units"""
         if units.lower() not in ["meters", "feet"]:
             raise KeyError("Valid units are `meters` or `feet`")
         self.dim = self.dim.with_(units=units)
 
         self.scene.dim = self.dim
-        self.scene.update_standard_zones(self.standard)
+        self.scene.update_standard_zones(
+            self.standard, preserve_spacing=preserve_spacing
+        )
         self.scene.to_units(unit_mode=unit_mode)
         return self
 
@@ -291,7 +301,9 @@ class Room:
         self.dim = self.dim.with_(x=x, y=y, z=z)
         self.ref_manager.update_dimensions(self.dim.x, self.dim.y, self.dim.z)
         self.scene.dim = self.dim
-        self.scene.update_standard_zones(self.standard, preserve_spacing=preserve_spacing)
+        self.scene.update_standard_zones(
+            self.standard, preserve_spacing=preserve_spacing
+        )
         return self
 
     @property
