@@ -166,28 +166,41 @@ class Scene:
 
         if "SkinLimits" in self.calc_zones.keys():
             zone = self.calc_zones["SkinLimits"]
-            zone.set_dimensions(x2=self.dim.x, y2=self.dim.y, preserve_spacing=preserve_spacing)
+            zone.set_dimensions(
+                x2=self.dim.x, y2=self.dim.y, preserve_spacing=preserve_spacing
+            )
             zone.set_height(height)
             zone.horiz = skin_horiz
         if "EyeLimits" in self.calc_zones.keys():
             zone = self.calc_zones["EyeLimits"]
-            zone.set_dimensions(x2=self.dim.x, y2=self.dim.y, preserve_spacing=preserve_spacing)
+            zone.set_dimensions(
+                x2=self.dim.x, y2=self.dim.y, preserve_spacing=preserve_spacing
+            )
             zone.set_height(height)
             zone.fov_vert = fov_vert
             zone.vert = eye_vert
         if "WholeRoomFluence" in self.calc_zones.keys():
             zone = self.calc_zones["WholeRoomFluence"]
-            zone.set_dimensions(x2=self.dim.x, y2=self.dim.y, z2=self.dim.z, preserve_spacing=preserve_spacing)
+            zone.set_dimensions(
+                x2=self.dim.x,
+                y2=self.dim.y,
+                z2=self.dim.z,
+                preserve_spacing=preserve_spacing,
+            )
 
     def check_positions(self):
         """
         verify the positions of all objects in the scene and return any warning messages
         """
-        msgs = []
+        lamps, zones = {}, {} 
         for lamp_id, lamp in self.lamps.items():
-            msgs.append(self._check_lamp_position(lamp))
+            lamps[lamp_id] = self._check_lamp_position(lamp)
         for zone_id, zone in self.calc_zones.items():
-            msgs.append(self._check_zone_position(zone))
+            zones[zone_id] = self._check_zone_position(zone)
+            
+        msgs = {}
+        msgs["lamps"] = lamps
+        msgs["calc_zones"] = zones
         return msgs
 
     def get_valid_lamps(self):
@@ -251,10 +264,9 @@ class Scene:
         return self._check_position(lamp.position, lamp.name)
 
     def _check_zone_position(self, calc_zone):
-        if isinstance(calc_zone, CalcPlane):
-            dimensions = [calc_zone.x2, calc_zone.y2]
-        elif isinstance(calc_zone, CalcVol):
-            dimensions = [calc_zone.x2, calc_zone.y2, calc_zone.z2]
+        if isinstance(calc_zone, (CalcPlane, CalcZone)):
+            x, y, z = calc_zone.coords.T
+            dimensions = x.max(), y.max(), z.max()       
         elif isinstance(calc_zone, CalcZone):
             # this is a hack; a generic CalcZone is just a placeholder
             dimensions = self.dim.dimensions()
